User's Guide
============

From a user's perspective, the only interface is the server website.
All interactions happen here: submitting a new dataset, monitoring
progress, viewing errors, resetting tasks, etc.

.. note::
   :class: icecube

   For IceCube users, see https://iceprod2.icecube.wisc.edu

Topics
------

.. toctree::
    :maxdepth: 2

    login
    submission
    datasets
    tasks
    restapi
    manually
